# DyNetx - Dynamic Network analysis library
[![Test and Coverage (Ubuntu)](https://github.com/GiulioRossetti/dynetx/actions/workflows/test_ubuntu.yml/badge.svg)](https://github.com/GiulioRossetti/dynetx/actions/workflows/test_ubuntu.yml)
[![codecov](https://codecov.io/gh/GiulioRossetti/dynetx/branch/master/graph/badge.svg?token=ILcIwMJDpm)](https://codecov.io/gh/GiulioRossetti/dynetx)
[![Documentation Status](https://readthedocs.org/projects/dynetx/badge/?version=latest)](http://dynetx.readthedocs.io/en/latest/?badge=latest)
[![pyversions](https://img.shields.io/pypi/pyversions/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![PyPI version](https://badge.fury.io/py/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![Updates](https://pyup.io/repos/github/GiulioRossetti/dynetx/shield.svg)](https://pyup.io/repos/github/GiulioRossetti/dynetx/)
[![Downloads](https://pepy.tech/badge/dynetx)](https://pepy.tech/project/dynetx)
[![Downloads](https://pepy.tech/badge/dynetx/month)](https://pepy.tech/project/dynetx)
[![DOI](https://zenodo.org/badge/98746676.svg)](https://zenodo.org/badge/latestdoi/98746676)
[![SBD++](https://img.shields.io/badge/Available%20on-SoBigData%2B%2B-green)](https://sobigdata.d4science.org/group/sobigdata-gateway/explore?siteId=20371853)

![DyNetx logo](http://dynetx.readthedocs.io/en/latest/_static/dynetx.png)


DyNetx provides implementations of dynamic networks in python (it is built upon [networkx](http://networkx.github.io)).

The project documentation can be found on [ReadTheDocs](http://dynetx.readthedocs.io).

If you would like to test ``DyNetx`` functionalities withouth installing anything on your machine consider using the preconfigured Jupyter Hub instances offered by [SoBigData++](https://sobigdata.d4science.org/group/sobigdata-gateway/explore?siteId=20371853).


## Citation

> Rossetti, G. (2020) DyNetx: dynamic network analysis library, v0.2.1, Zenodo, doi: 10.5281/zenodo.3953119


## Installation

In order to install the library  use pip:
```bash
pip install dynetx
```

or conda:

```bash
conda install -c giuliorossetti dynetx
```

